@@ -95,126 +95,23 @@ function enigmailRefreshKeys() {
   enigApplyFilter();
 }
 
-function enigLoadKeyList(secretOnly, refresh) {
-  DEBUG_LOG("enigmailMessengerOverlay.js: enigLoadKeyList\n");
-
-  try {
-    var exitCodeObj = new Object();
-    var statusFlagsObj = new Object();
-    var errorMsgObj = new Object();
-    
-    var enigmailSvc = GetEnigmailSvc();
-    if (! enigmailSvc) 
-      return null;
-    var userList = enigmailSvc.getUserIdList(secretOnly,
-                                             refresh,
-                                             exitCodeObj,
-                                             statusFlagsObj,
-                                             errorMsgObj);
-    if (exitCodeObj.value != 0) {
-      EnigAlert(errorMsgObj.value);
-      return null;
-    }
-  } catch (ex) {
-    ERROR_LOG("ERROR in enigmailUserSelection: enigLoadKeyList\n");
-  }
-
-  if (typeof(userList) == "string") {
-    return userList.split(/\n/);
-  }
-  else {
-    return [];
-  }
-}
-
 
 function enigmailBuildList(refresh) {
   DEBUG_LOG("enigmailUserSelection.js: enigmailBuildList\n");
+
+  var keyListObj = {};
+
+  EnigLoadKeyList(refresh, keyListObj);
   
-  var sortUsers = function (a, b) {
-  
-   if (a.userId.toLowerCase()<b.userId.toLowerCase()) { return -1;} else {return 1; }
-  
-  }
-  
-  var aGpgUserList = enigLoadKeyList(false, refresh);
-  if (!aGpgUserList) return;
-  
-  var aGpgSecretsList = enigLoadKeyList(true, refresh);
-  if (!aGpgSecretsList && !refresh) {
-    if (EnigConfirm(EnigGetString("noSecretKeys"))) {
-      EnigKeygen();
-      enigmailRefreshKeys(true);
-    }
-  }
+  gKeyList = keyListObj.keyList;
+  gKeySortList = keyListObj.keySortList;
 
   gUserList.currentItem=null;
-  
+
   var treeChildren=document.getElementById("pgpKeyListChildren");
-  
-  gKeyList = new Array();
-  var gKeySortList = new Array();
-  
-  var keyObj = new Object();
-  var i;
-  
-  for (i=0; i<aGpgUserList.length; i++) {
-    var listRow=aGpgUserList[i].split(/:/);
-    if (listRow.length>=0) {
-      switch (listRow[0]) {
-      case "pub":
-        keyObj = new Object();
-        keyObj.expiry=listRow[EXPIRY];
-        keyObj.created=listRow[CREATED];
-        keyObj.userId=EnigConvertGpgToUnicode(listRow[USER_ID].replace(/\\e3A/g, ":"));
-        keyObj.keyId=listRow[KEY_ID];
-        keyObj.keyTrust=listRow[KEY_TRUST];
-        keyObj.keyUseFor=listRow[KEY_USE_FOR];
-        keyObj.ownerTrust=listRow[OWNERTRUST];
-        keyObj.SubUserIds=new Array();
-        keyObj.fpr="";
-        keyObj.photoAvailable=false;
-        keyObj.secretAvailable=false;
-        gKeyList[listRow[KEY_ID]] = keyObj;
-        gKeySortList.push({userId: keyObj.userId, keyId: keyObj.keyId});
-        break;
-      case "fpr":
-        keyObj.fpr=listRow[USER_ID];
-        break;
-      case "uid":
-        var subUserId = {
-          userId: EnigConvertGpgToUnicode(listRow[USER_ID].replace(/\\e3A/g, ":")),
-          keyTrust: listRow[KEY_TRUST],
-          type: "uid"
-        }
-        keyObj.SubUserIds.push(subUserId);
-        break;
-      case "uat":
-        if (listRow[USER_ID].indexOf("1 ")==0) {
-          var userId=EnigGetString("userAtt.photo");
-          keyObj.SubUserIds.push({userId: userId, keyTrust:"", type: "uat"});
-          keyObj.photoAvailable=true;
-        }
-      }
-    }
-  }
-  
-  // search and mark keys that have secret keys
-  for (i=0; i<aGpgSecretsList.length; i++) {
-     listRow=aGpgSecretsList[i].split(/:/);
-     if (listRow.length>=0) {
-       if (listRow[0] == "sec") {
-         if (typeof(gKeyList[listRow[KEY_ID]]) == "object") {
-           gKeyList[listRow[KEY_ID]].secretAvailable=true;
-         }
-       }
-     }
-  }
- 
-  gKeySortList.sort(sortUsers);
- 
+
   var selectedItems=[];
-  for (i=0; i < gKeySortList.length; i++) {
+  for (var i=0; i < gKeySortList.length; i++) {
     var keyId = gKeySortList[i].keyId;
     if (gEnigLastSelectedKeys && typeof(gEnigLastSelectedKeys[keyId]) != "undefined")
       selectedItems.push(i);
@@ -242,9 +139,7 @@ function enigmailBuildList(refresh) {
       gUserList.view.selection.rangedSelect(selectedItems[i], selectedItems[i], true)
     }
   }
-  else {
-    gUserList.view.selection.select(0);
-  }
+  gUserList.focus();
 }
 
 
@@ -286,13 +181,51 @@ function enigUserSelCreateRow (keyObj, subKeyNum) {
     }
     var keyTrustLabel = EnigGetTrustLabel(keyTrust);
 
+    var keyTrustStyle="";
+    switch (keyTrust) {
+    case 'q':
+      keyTrustStyle="enigmail_keyValid_unknown";
+      break;
+    case 'i':
+      keyTrustStyle="enigmail_keyValid_invalid";
+      break;
+    case 'd':
+      keyTrustStyle="enigmail_keyValid_disabled";
+      break;
+    case 'r':
+      keyTrustStyle="enigmail_keyValid_revoked";
+      break;
+    case 'e':
+      keyTrustStyle="enigmail_keyValid_expired";
+      break;
+    case 'n':
+      keyTrustStyle="enigmail_keyTrust_untrusted";
+      break;
+    case 'm':
+      keyTrust="enigmail_keyTrust_marginal";
+      break;
+    case 'f':
+      keyTrustStyle="enigmail_keyTrust_full";
+      break;
+    case 'u':
+      keyTrustStyle="enigmail_keyTrust_ultimate";
+      break;
+    case '-':
+    default:
+      keyTrustStyle="enigmail_keyTrust_unknown";
+      break;
+    }
+
     expCol.setAttribute("label", keyObj.expiry);
     expCol.setAttribute("id", "expiry");
 
     if (keyObj.keyUseFor.indexOf("D")>=0) {
       keyTrustLabel=EnigGetString("keyValid.disabled");
+      keyTrustStyle="enigmail_keyValid_disabled";
     }
+    
     validCol.setAttribute("label", keyTrustLabel);
+    validCol.setAttribute("properties", keyTrustStyle);
 
     trustCol.setAttribute("label", EnigGetTrustLabel(keyObj.ownerTrust));
     
@@ -313,12 +246,18 @@ function enigUserSelCreateRow (keyObj, subKeyNum) {
         (KEY_NOT_VALID.indexOf(keyTrust.charAt(0))>=0) ||
         (keyObj.keyUseFor.indexOf("D")>=0)) {
       for (var node=userRow.firstChild; node; node=node.nextSibling) {
-        node.setAttribute("properties", "enigKeyInactive");
+        var attr=node.getAttribute("properties");
+        if (typeof(attr)=="string") {
+          node.setAttribute("properties", attr+" enigKeyInactive");
+        }
+        else {
+          node.setAttribute("properties", "enigKeyInactive");
+        }
       }
     }
     if (keyObj.secretAvailable && subKeyNum <0) {
       for (node=userRow.firstChild; node; node=node.nextSibling) {
-        var attr=node.getAttribute("properties");
+        attr=node.getAttribute("properties");
         if (typeof(attr)=="string") {
           node.setAttribute("properties", attr+" enigmailOwnKey");
         }
@@ -372,27 +311,44 @@ function enigmailKeyMenu() {
   else {
     document.getElementById("bcViewPhoto").setAttribute("disabled", "true");
   }
+  
+  if (enigGetClipboard().length > 0) {
+    document.getElementById("bcClipbrd").removeAttribute("disabled");
+  }
+  else {
+    document.getElementById("bcClipbrd").setAttribute("disabled", "true");
+  }
 
+  if (keyList.length >= 1) {
+    document.getElementById("bcEnableKey").removeAttribute("disabled");
+    if (gKeyList[keyList[0]].keyUseFor.indexOf("D")>0 ||
+        gKeyList[keyList[0]].keyTrust.indexOf(KEY_DISABLED)>=0) {
+      document.getElementById("bcEnableKey").setAttribute("label", EnigGetString("keyMan.enableKey"))
+    }
+    else {
+      document.getElementById("bcEnableKey").setAttribute("label", EnigGetString("keyMan.disableKey"))
+    }
+  }
+  
   if (keyList.length == 1) {
     document.getElementById("bcSignKey").removeAttribute("disabled");
     document.getElementById("bcViewSig").removeAttribute("disabled");
     document.getElementById("bcKeyDetails").removeAttribute("disabled");
     document.getElementById("bcDeleteKey").removeAttribute("disabled");
-    document.getElementById("bcEnableKey").removeAttribute("disabled");
-    if (gKeyList[keyList[0]].keyUseFor.indexOf("D")>0 || 
-        gKeyList[keyList[0]].keyTrust.indexOf(KEY_DISABLED)>=0) {
-      document.getElementById("bcEnableKey").setAttribute("label", EnigGetString("keyMan.enableKey"))
-    } 
-    else {
-      document.getElementById("bcEnableKey").setAttribute("label", EnigGetString("keyMan.disableKey"))
-    }
+    document.getElementById("bcNoKey").removeAttribute("disabled");
   }
   else {
+    if (keyList.length == 0) {
+      document.getElementById("bcNoKey").setAttribute("disabled", "true");
+      document.getElementById("bcEnableKey").setAttribute("disabled", "true");
+    }
+    else {
+      document.getElementById("bcNoKey").removeAttribute("disabled");
+    }
     document.getElementById("bcSignKey").setAttribute("disabled", "true");
     document.getElementById("bcViewSig").setAttribute("disabled", "true");
     document.getElementById("bcKeyDetails").setAttribute("disabled", "true");
     document.getElementById("bcDeleteKey").setAttribute("disabled", "true");
-    document.getElementById("bcEnableKey").setAttribute("disabled", "true");
   }
 }
 
@@ -420,6 +376,10 @@ function enigmailDblClick(event) {
   }
 }
 
+function enigmailSelectAllKeys() {
+  gUserList.view.selection.selectAll();
+}
+
 function enigmailKeyDetails() {
   var keyList = enigmailGetSelectedKeys();
 
@@ -434,29 +394,42 @@ function enigmailKeyDetails() {
 
 function enigmailDeleteKey() {
   var keyList = enigmailGetSelectedKeys();
+  var deleteSecret=false;
 
   var enigmailSvc = GetEnigmailSvc();
   if (!enigmailSvc)
     return;
 
-  var userId="0x"+keyList[0].substr(-8,8)+" - "+gKeyList[keyList[0]].userId;
-  var deleteSecret=false;
-  if(gKeyList[keyList[0]].secretAvailable) {
-    if (!EnigConfirm(EnigGetString("deleteSecretKey", userId))) return;
-    deleteSecret=true;
+  if (keyList.length == 1) {
+    // one key selected
+    var userId="0x"+keyList[0].substr(-8,8)+" - "+gKeyList[keyList[0]].userId;
+    if(gKeyList[keyList[0]].secretAvailable) {
+      if (!EnigConfirm(EnigGetString("deleteSecretKey", userId))) return;
+      deleteSecret=true;
+    }
+    else {
+      if (!EnigConfirm(EnigGetString("deletePubKey", userId))) return;
+    }
   }
   else {
-    if (!EnigConfirm(EnigGetString("deletePubKey", userId))) return;
+    // several keys selected
+    for (var i=0; i<keyList.length; i++) {
+      if (gKeyList[keyList[i]].secretAvailable) deleteSecret = true;
+    }
+    
+    if (deleteSecret) {
+      if (!EnigConfirm(EnigGetString("deleteMix"))) return;
+    }
+    else {
+      if (!EnigConfirm(EnigGetString("deleteSelectedPubKey"))) return;
+    }
   }
   
   var errorMsgObj = {};
-  var r=enigmailSvc.deleteKey(window, "0x"+keyList[0], deleteSecret, errorMsgObj);
+  var r=enigmailSvc.deleteKey(window, "0x"+keyList.join(" 0x"), deleteSecret, errorMsgObj);
   if (r != 0) {
     EnigAlert(EnigGetString("deleteKeyFailed")+"\n\n"+errorMsgObj.value);
   }
-  else {
-    EnigAlert(EnigGetString("deleteKeyOk"));
-  }
   enigmailRefreshKeys();
 }
 
@@ -470,10 +443,13 @@ function enigmailEnableKey() {
   if (!enigmailSvc)
     return;
 
-  var errorMsgObj = {};
-  var r=enigmailSvc.enableDisableKey(window, "0x"+keyList[0], disableKey, errorMsgObj);
-  if (r != 0) {
-    EnigAlert(EnigGetString("enableKeyFailed")+"\n\n"+errorMsgObj.value);
+  for (var i=0; i<keyList.length; i++) {
+    var errorMsgObj = {};
+    var r=enigmailSvc.enableDisableKey(window, "0x"+keyList[i], disableKey, errorMsgObj);
+    if (r != 0) {
+      EnigAlert(EnigGetString("enableKeyFailed")+"\n\n"+errorMsgObj.value);
+      break;
+    }
   }
   enigmailRefreshKeys();
 }
@@ -484,8 +460,71 @@ function enigShowPhoto() {
   EnigShowPhoto(keyList[0], gKeyList[keyList[0]].userId);
 }
 
+function enigCreateKeyMsg() {
+  var enigmailSvc = GetEnigmailSvc();
+  if (!enigmailSvc)
+    return;
+
+  var keyList = enigmailGetSelectedKeys();
+  if (keyList.length==0) {
+    EnigAlert(EnigGetString("noKeySelected"));
+    return;
+  }
+
+  var tmpDir=EnigGetTempDir();
+
+  try {
+    var tmpFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
+    tmpFile.initWithPath(tmpDir);
+    if (!(tmpFile.isDirectory() && tmpFile.isWritable())) {
+      EnigAlert(EnigGetString("noTempDir"));
+      return;
+    }
+  }
+  catch (ex) {}
+  tmpFile.append("key.asc");
+  tmpFile.createUnique(Components.interfaces.nsIFile.NORMAL_FILE_TYPE, 0600);
+
+  // save file
+  var exitCodeObj= {};
+  var errorMsgObj = {};
+  enigmailSvc.extractKey(window, 0, "0x"+keyList.join(" 0x"), tmpFile.path, exitCodeObj, errorMsgObj);
+  if (exitCodeObj.value != 0) {
+    EnigAlert(errorMsgObj.value);
+    return;
+  }
+
+  // create attachment
+  var ioServ = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+  var tmpFileURI = ioServ.newFileURI(tmpFile);
+  var keyAttachment = Components.classes["@mozilla.org/messengercompose/attachment;1"].createInstance(Components.interfaces.nsIMsgAttachment);
+  keyAttachment.url = tmpFileURI.spec;
+  if (keyList.length == 1) {
+    keyAttachment.name = "0x"+keyList[0].substr(-8,8)+".asc"
+  }
+  else {
+    keyAttachment.name = "pgpkeys.asc";
+  }
+  keyAttachment.temporary = true;
+  keyAttachment.contentType = "application/pgp-keys";
+  
+  // create Msg
+  var msgCompFields = Components.classes["@mozilla.org/messengercompose/composefields;1"].createInstance(Components.interfaces.nsIMsgCompFields);
+  msgCompFields.addAttachment(keyAttachment);
+
+  var acctManager = Components.classes["@mozilla.org/messenger/account-manager;1"].createInstance(Components.interfaces.nsIMsgAccountManager);
+  
+  var msgCompSvc = Components.classes["@mozilla.org/messengercompose;1"].getService(Components.interfaces.nsIMsgComposeService);
+  msgCompSvc.OpenComposeWindowWithCompFields ("",
+            Components.interfaces.nsIMsgCompType.New,
+            Components.interfaces.nsIMsgCompFormat.Default,
+            msgCompFields,
+            acctManager.defaultAccount.defaultIdentity);
+}
+
 
 function enigEditKeyTrust() {
+
   var keyList = enigmailGetSelectedKeys();
   if (keyList.length==0) {
     EnigAlert(EnigGetString("noKeySelected"));
@@ -660,9 +699,14 @@ function enigmailListSig() {
     keyId: keyList[0],
     keyListArr: gKeyList
   };
+  var resultObj = {};
   
   window.openDialog("chrome://enigmail/content/enigmailViewKeySigDlg.xul",
-        "", "dialog,modal,centerscreen,resizable=yes", inputObj);
+        "", "dialog,modal,centerscreen,resizable=yes", inputObj, resultObj);
+        
+  if (resultObj.refresh) {
+    enigmailRefreshKeys();
+  }
         
 }
 
@@ -677,14 +721,9 @@ function enigmailManageUids() {
   enigmailRefreshKeys();
 }
 
-function enigmailImportFromClipbrd() {
-  var enigmailSvc = GetEnigmailSvc();
-  if (!enigmailSvc)
-    return;
-
-  if (!EnigConfirm(EnigGetString("importFromClip"))) {
-    return;
-  }
+function enigGetClipboard() {
+  DEBUG_LOG("enigmailKeyManager.js: enigGetClipboard:\n");
+  var cBoardContent = "";
   var clipBoard = Components.classes[ENIG_CLIPBOARD_CONTRACTID].getService(Components.interfaces.nsIClipboard);
   try {
     var transferable = Components.classes[ENIG_TRANSFERABLE_CONTRACTID].createInstance(Components.interfaces.nsITransferable);
@@ -694,11 +733,23 @@ function enigmailImportFromClipbrd() {
     var data = {};
     var length = {};
     transferable.getAnyTransferData(flavour, data, length);
-    var cBoardContent=data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
-    DEBUG_LOG("enigmailKeyManager.js: enigmailImportFromClipbrd: got data from clipboard");
+    cBoardContent=data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
+    DEBUG_LOG("enigmailKeyManager.js: enigGetClipboard: got data\n");
   }
   catch(ex) {}
+  return cBoardContent;
+}
 
+function enigmailImportFromClipbrd() {
+  var enigmailSvc = GetEnigmailSvc();
+  if (!enigmailSvc)
+    return;
+
+  if (!EnigConfirm(EnigGetString("importFromClip"))) {
+    return;
+  }
+
+  var cBoardContent = enigGetClipboard();
   var errorMsgObj = {};
   var r=enigmailSvc.importKey(window, 0, cBoardContent, "", errorMsgObj);
   EnigLongAlert(errorMsgObj.value);
@@ -773,6 +824,12 @@ function enigmailReceiveKey() {
   enigmailKeyServerAcess(nsIEnigmail.DOWNLOAD_KEY, enigmailReceiveKeyCb);
 }
 
+function enigmailRefreshAllKeys() {
+
+  EnigAlertPref(EnigGetString("refreshKey.warn"), "warnRefreshAll");
+  enigmailKeyServerAcess(nsIEnigmail.REFRESH_KEY, enigmailReceiveKeyCb);
+}
+
 function enigmailReceiveKeyCb(exitCode, errorMsg, msgBox) {
   if (msgBox) {
     if (exitCode==0) {
@@ -866,7 +923,6 @@ function enigApplyFilter() {
   }
 }
 
-
 //
 // ----- keyserver related functionality ----
 //
@@ -877,159 +933,50 @@ function enigmailKeyServerAcess(accessType, callbackFunc) {
     return;
 
   var resultObj = {};
-  
+  var inputObj = {};
   if (accessType == nsIEnigmail.UPLOAD_KEY) {
-    var inputObj = {
-       upload: true
-    };
+    inputObj.upload = true;
+  }
+
+  var selKeyList = enigmailGetSelectedKeys();
+  if (accessType != nsIEnigmail.REFRESH_KEY && selKeyList.length==0) {
+    if (EnigConfirm(EnigGetString("refreshAllQuestion"))) {
+      accessType = nsIEnigmail.REFRESH_KEY;
+      EnigAlertPref(EnigGetString("refreshKey.warn"), "warnRefreshAll");
+    }
+    else {
+      return;
+    }
+  }
+
+  if (accessType != nsIEnigmail.REFRESH_KEY) {
+    var keyList=[];
+    for (var i=0; i < selKeyList.length; i++) {
+      keyList.push("0x"+selKeyList[i].substr(-8,8)+" - "+ gKeyList[selKeyList[i]].userId);
+    }
+    inputObj.keyId = keyList.join(", ");
   }
   else {
-    inputObj = {};
+    inputObj.keyId = "";
   }
-    
-  var selKeyList = enigmailGetSelectedKeys();
-  if (selKeyList.length==0) {
-    EnigAlert(EnigGetString("noKeySelected"));
-    return;
-  }
-  
-  var keyList=[];
-  for (var i=0; i < selKeyList.length; i++) {
-    keyList.push("0x"+selKeyList[i].substr(-8,8)+" - "+ gKeyList[selKeyList[i]].userId); 
-  }
-  inputObj.keyId = keyList.join(", ");
   
   window.openDialog("chrome://enigmail/content/enigmailKeyserverDlg.xul",
         "", "dialog,modal,centerscreen", inputObj, resultObj);
   if (! resultObj.value) {
     return;
   }
-  
-  var progressBar=Components.classes["@mozilla.org/messenger/progress;1"].createInstance(Components.interfaces.nsIMsgProgress);
-  var requestObserver = new EnigRequestObserver(enigSendKeyTerminate, {'progressBar': progressBar, 'callType': 1});
 
-  var progressListener = {
-      onStateChange: function(aWebProgress, aRequest, aStateFlags, aStatus)
-      {
-        if (aStateFlags & Components.interfaces.nsIWebProgressListener.STATE_STOP) {
-          if (progressBar.processCanceledByUser)
-            enigSendKeyCancel(progressBar);
-        }
-      },
-
-      onProgressChange: function(aWebProgress, aRequest, aCurSelfProgress, aMaxSelfProgress, aCurTotalProgress, aMaxTotalProgress)
-      {},
-
-      onLocationChange: function(aWebProgress, aRequest, aLocation)
-      {},
-
-      onStatusChange: function(aWebProgress, aRequest, aStatus, aMessage)
-      {},
-
-      onSecurityChange: function(aWebProgress, aRequest, state)
-      {},
-
-      QueryInterface : function(iid)
-      {
-        if (iid.equals(Components.interfaces.nsIWebProgressListener) ||
-            iid.equals(Components.interfaces.nsISupportsWeakReference) ||
-            iid.equals(Components.interfaces.nsISupports))
-          return this;
-
-        throw Components.results.NS_NOINTERFACE;
-      }
+  var keyDlObj = {
+    accessType: accessType,
+    keyServer: resultObj.value,
+    keyList: "0x"+selKeyList.join(" 0x"),
+    cbFunc: callbackFunc
   };
-  progressBar.registerListener(progressListener);
-     
-  var errorMsgObj={};
-  gEnigIpcRequest = enigmailSvc.receiveKey(accessType, resultObj.value, "0x"+selKeyList.join(" 0x"), requestObserver, errorMsgObj);
-  if (gEnigIpcRequest == null) {
-    callbackFunc(-1, errorMsgObj.value, true);
-    return;
-  }
-  gEnigCallbackFunc = callbackFunc;
-  if (accessType == nsIEnigmail.UPLOAD_KEY) {
-    document.getElementById("statusText").value=EnigGetString("uploadingKey");
-  }
-  else {
-    document.getElementById("statusText").value=EnigGetString("downloadingKey");
-  }
-  document.getElementById("progressBar").removeAttribute("collapsed");
-  document.getElementById("cancelBox").removeAttribute("collapsed");
-}
-
-
-function enigSendKeyTerminate (terminateArg, ipcRequest) {
-  DEBUG_LOG("enigmailKeyManager.js: enigSendKeyTerminate\n");
-
-  if (terminateArg && terminateArg.progressBar) {
-    terminateArg.progressBar.onStateChange(null, null, Components.interfaces.nsIWebProgressListener.STATE_STOP, 0);
-  }
-
-  if (gEnigIpcRequest) {
-    var cbFunc = gEnigCallbackFunc;
-    var keyRetrProcess = gEnigIpcRequest.pipeTransport;
-    var exitCode;
-    var statusText = document.getElementById("statusText");
-    document.getElementById("progressBar").setAttribute("collapsed", "true");
-    document.getElementById("cancelBox").setAttribute("collapsed", "true");
-    
-    var enigmailSvc = GetEnigmailSvc();
-    if (keyRetrProcess && !keyRetrProcess.isAttached()) {
-      keyRetrProcess.terminate();
-      exitCode = keyRetrProcess.exitCode();
-      DEBUG_LOG("enigmailKeyManager.js: enigSendKeyTerminate: exitCode = "+exitCode+"\n");
-      if (enigmailSvc) {
-        exitCode = enigmailSvc.fixExitCode(exitCode, 0);
-      }
-    }
   
-    statusText.value=cbFunc(exitCode, "", false);
-    
-    var errorMsg="";
-    try {
-      var gpgConsole = gEnigIpcRequest.stderrConsole.QueryInterface(Components.interfaces.nsIPipeConsole);
-
-      if (gpgConsole && gpgConsole.hasNewData()) {
-        errorMsg = gpgConsole.getData();
-        if (enigmailSvc) {
-          var statusFlagsObj=new Object();
-          var statusMsgObj=new Object();
-          errorMsg=enigmailSvc.parseErrorOutput(errorMsg, statusFlagsObj, statusMsgObj);
-        }
-      }
-    } catch (ex) {}
-    
-    DEBUG_LOG("enigmailKeyManager.js: enigSendKeyTerminate: errorMsg="+errorMsg);
-    if (errorMsg.search(/ec=\d+/i)>=0) {
-      exitCode=-1;
-    }
-    statusText.value=cbFunc(exitCode, "", false);
-    cbFunc(exitCode, errorMsg, true);
-
-    window.setTimeout(enigHideStatus, 5000);
-    gEnigIpcRequest.close(true);
+  window.openDialog("chrome://enigmail/content/enigRetrieveProgress.xul",
+        "", "dialog,modal,centerscreen", keyDlObj, resultObj);
+        
+  if (accessType != nsIEnigmail.UPLOAD_KEY && resultObj.result) {
+    enigmailRefreshKeys();
   }
 }
-
-function enigSendKeyCancel() {
-  document.getElementById("cancelButton").setAttribute("collapsed", "true");
-  var keyRetrProcess = gEnigIpcRequest.pipeTransport;
-
-  if (keyRetrProcess && !keyRetrProcess.isAttached()) {
-    keyRetrProcess.terminate();
-  }
-  gEnigIpcRequest.close(true);
-  document.getElementById("statusText").value=EnigGetString("keyserverAccessAborted");
-  document.getElementById("progressBar").setAttribute("collapsed", "true");
-  window.setTimeout(enigHideStatus, 5000);
-  gEnigIpcRequest=null;
-  gEnigCallbackFunc=null;
-}
-
-function enigHideStatus() {
-  document.getElementById("statusText").value="";
-  document.getElementById("progressBar").setAttribute("collapsed", "true");
-  document.getElementById("cancelBox").setAttribute("collapsed", "true");
-}
-
