@@ -159,12 +159,8 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
 
   gEnigLastEncryptedURI = GetLoadedMessage();
   var bodyElement = document.getElementById("messagepanebox");
-/*
-  var bodyElement = msgFrame.document.getElementsByTagName("body")[0];
-  if (! bodyElement) {
-    bodyElement = msgFrame.frames.document.body;
-  }
-*/
+
+  if (!errorMsg) errorMsg="";
 
   if (userId && (userId.indexOf("\n")>=0)) {
     var replaceUid=enigMatchUidToSender(userId);
@@ -172,6 +168,9 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     userId=EnigConvertGpgToUnicode(replaceUid);
   }
 
+  if (userId) {
+    userId=userId.replace(/\\[xe]3a/gi, ":");
+  }
   var errorLines="";
   var fullStatusInfo="";
 
@@ -180,7 +179,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
   }
   else {
     if (errorMsg) {
-      errorMsg=EnigConvertGpgToUnicode(errorMsg);
+      errorMsg=EnigConvertGpgToUnicode(errorMsg).replace(/\\[xe]3a/gi, ":");
       errorLines = errorMsg.split(/\r?\n/);
       fullStatusInfo=errorMsg;
     }
@@ -251,14 +250,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     if (sigDetails) {
       var detailArr=sigDetails.split(/ /);
 
-      var dat=new Date(detailArr[2]*1000);
-      var appLocale = Components.classes[ENIG_LOCALE_SVC_CONTRACTID].getService(Components.interfaces.nsILocaleService).getApplicationLocale();
-      var dateFormat = Components.classes[ENIG_DATE_FORMAT_CONTRACTID].getService(Components.interfaces.nsIScriptableDateFormat);
-      dateTime = dateFormat.FormatDateTime(appLocale.getCategory("NSILOCALE_TIME"), 
-                          dateFormat.dateFormatShort,
-                          dateFormat.timeFormatNoSeconds,
-                          dat.getFullYear(), dat.getMonth()+1, dat.getDate(),
-                          dat.getHours(), dat.getMinutes(), 0);
+      dateTime = EnigGetDateTime(detailArr[2], true, true);
       var txt = EnigGetString("keyAndSigDate", keyId.substr(-8, 8), dateTime);
       statusArr.push(txt);
       statusInfo += "\n" + txt;
@@ -654,35 +646,16 @@ addEventListener('messagepane-unhide', enigMsgHdrViewUnhide, true);
 // THE FOLLOWING OVERRIDES CODE IN msgHdrViewOverlay.js
 
 
-var fEnigOpenAttachment;
-try {
-  // Mozilla <= 1.5
-  if (openAttachment) {
-    fEnigOpenAttachment = openAttachment;
-    openAttachment = function (msg) {
-      DEBUG_LOG("enigmailMsgHdrViewOverlay.js: openAttachment: "+msg.contentType+"\n");
-
-      if (msg.contentType.search(/^message\/rfc822/i) == 0) {
-        // Reset mail.show_headers pref to "original" value
-        EnigShowHeadersAll(false);
-      }
-
-      fEnigOpenAttachment(msg);
-    }
-  }
-} catch (ex) {
-  // Mozilla >= 1.6a
-  if (createNewAttachmentInfo.prototype.openAttachment) {
-    createNewAttachmentInfo.prototype.origOpenAttachment = createNewAttachmentInfo.prototype.openAttachment;
-    createNewAttachmentInfo.prototype.openAttachment = function () {
-      if (this.contentType.search(/^message\/rfc822/i) == 0) {
-        // Reset mail.show_headers pref to "original" value
-        EnigShowHeadersAll(false);
-      }
-
-      this.origOpenAttachment();
+// for Mozilla >= 1.6a only
+if (createNewAttachmentInfo.prototype.openAttachment) {
+  createNewAttachmentInfo.prototype.origOpenAttachment = createNewAttachmentInfo.prototype.openAttachment;
+  createNewAttachmentInfo.prototype.openAttachment = function () {
+    if (this.contentType.search(/^message\/rfc822/i) == 0) {
+      // Reset mail.show_headers pref to "original" value
+      EnigShowHeadersAll(false);
     }
 
+    this.origOpenAttachment();
   }
 }
 
