@@ -39,11 +39,12 @@ EnigInitCommon("enigmailSearchKey");
 const INPUT = 0;
 const RESULT = 1;
 
-const ENIG_DEFAULT_HKP_PORT="11371";
+const ENIG_DEFAULT_HKP_PORT  = "11371";
+const ENIG_DEFAULT_LDAP_PORT = "389";
 
-const ENIG_IMG_NOT_SELECTED ="chrome://enigmail/content/check0.png";
-const ENIG_IMG_SELECTED     ="chrome://enigmail/content/check1.png";
-const ENIG_IMG_DISABLED     ="chrome://enigmail/content/check2.png";
+const ENIG_IMG_NOT_SELECTED = "chrome://enigmail/content/check0.png";
+const ENIG_IMG_SELECTED     = "chrome://enigmail/content/check1.png";
+const ENIG_IMG_DISABLED     = "chrome://enigmail/content/check2.png";
 
 const ENIG_CONN_TYPE_HTTP    = 1;
 const ENIG_CONN_TYPE_GPGKEYS = 2;
@@ -100,8 +101,17 @@ function onLoad () {
   else {
     protocol="hkp";
   }
+
+  var port="";
+  switch (protocol) {
+  case "hkp":
+    port = ENIG_DEFAULT_HKP_PORT;
+    break;
+  case "ldap":
+    port = ENIG_DEFAULT_LDAP_PORT;
+    break;
+  }
   
-  var port = ENIG_DEFAULT_HKP_PORT;
   var m = keyserver.match(/^(.+)(:)(\d+)$/);
   if (m && m.length==4) {
     keyserver = m[1];
@@ -338,7 +348,7 @@ function enigScanKeys(connType, htmlTxt) {
       enigScanHtmlKeys(htmlNode.firstChild.firstChild.data);
       break;
     case ENIG_CONN_TYPE_GPGKEYS:
-      enigScanGpgKeys(EnigConvertGpgToUnicode(htmlTxt));
+      enigScanGpgKeys(EnigConvertGpgToUnicode(unescape(htmlTxt)));
       break;
     default:
       ERROR_LOG("bizarre connType: "+connType+"\n");
@@ -389,7 +399,7 @@ function enigScanHtmlKeys (txt) {
           uid: []
         };
         if (m[4].search(/.+<.+@.+>/)>=0) {
-          key.uid.push(trim(m[4]));
+          if (! ignoreUid(m[4])) key.uid.push(trim(m[4]));
         }
         else if (m[4].search(/key (revoked|expired|disabled)/i)>=0) {
           DEBUG_LOG("revoked key id "+m[4]+"\n");
@@ -401,7 +411,7 @@ function enigScanHtmlKeys (txt) {
       // amend to key
       if (key) {
         var uid = trim(lines[i]);
-        if (uid.length>0)
+        if (uid.length>0 && ! ignoreUid(uid))
           key.uid.push(uid);
       }
     }
@@ -420,7 +430,7 @@ function enigScanGpgKeys(txt) {
   var lines=txt.split(/(\r\n|\n|\r)/);
   var outputType=0;
   var key;
-  for (i=0; i<lines.length; i++) {
+  for (var i=0; i<lines.length; i++) {
     if (outputType == 0 && lines[i].search(/^COUNT \d+\s*$/)==0) {
       outputType=1;
       continue;
@@ -435,7 +445,7 @@ function enigScanGpgKeys(txt) {
       if (m && m.length>0 ) {
         if (key) {
           if (key.keyId == m[0]) {
-            key.uid.push(trim(m[1]));
+            if (! ignoreUid(m[i])) key.uid.push(trim(m[1]));
           }
           else {
             window.enigRequest.keyList.push(key);
@@ -449,8 +459,9 @@ function enigScanGpgKeys(txt) {
           key={
             keyId: m[0],
             created: dat.getFullYear()+"-"+month+"-"+day,
-            uid: [m[1]]
+            uid: []
           };
+          if (! ignoreUid(m[1])) key.uid.push(m[1]);
         }
       }
     }
@@ -473,13 +484,12 @@ function enigScanGpgKeys(txt) {
         };
       }
     }
-    if (outputType==2 && (lines[i].search(/^uid:.*:.*:.*:.*$/))==0) {
+    if (outputType==2 && (lines[i].search(/^uid:.+/))==0) {
       // output from gpgkeys_* protocol version 1
       // uid for key
       m=lines[i].split(/:/);
       if (m && m.length>1 ) {
-        if (key)
-          key.uid.push(trim(m[1]));
+        if (key && ! ignoreUid(m[1])) key.uid.push(trim(m[1]));
       }
     }
   }
@@ -624,6 +634,10 @@ function enigPopulateList(keyList) {
     }
     treeChildren.appendChild(treeItem);
   }
+  
+  if (keyList.length == 1) {
+    enigSetActive(treeItem.firstChild.firstChild, 1);
+  }
 }
 
 function enigUserSelCreateRow (keyId, subKey, userId, dateField, trustStatus) {
@@ -721,3 +735,8 @@ function enigSetActive(element, status) {
     element.setAttribute("active", -1);
   }
 }
+
+function ignoreUid(uid) {
+  const ignoreList = "{Test 555 <sdfg@gga.com>}";
+  return (ignoreList.indexOf("{"+trim(uid)+"}") >= 0);
+}
